bluetooth_mesh.messages
================

.. autoconstruct:: bluetooth_mesh.messages.AccessMessage
   :noindex:
   :level: 0

Config
------

.. automodule:: bluetooth_mesh.messages.config

.. autoclass:: ConfigOpcode

.. autoconstruct:: ConfigMessage

Health
------

.. automodule:: bluetooth_mesh.messages.health

.. autoclass:: HealthOpcode

.. autoconstruct:: HealthMessage

Debug
-----

.. automodule:: bluetooth_mesh.messages.silvair.debug

.. autoclass:: DebugOpcode

.. autoclass:: DebugSubOpcode

.. autoconstruct:: DebugMessage

Network Diagnostic
------------------

Server
~~~~~~

.. automodule:: bluetooth_mesh.messages.silvair.network_diagnostic_server

.. autoclass:: NetworkDiagnosticServerOpcode

.. autoclass:: NetworkDiagnosticServerSubOpcode

.. autoconstruct:: NetworkDiagnosticServerMessage

Setup Server
~~~~~~~~~~~~

.. autoclass:: NetworkDiagnosticSetupServerOpcode

.. autoclass:: NetworkDiagnosticSetupServerSubOpcode

.. autoconstruct:: NetworkDiagnosticSetupServerMessage
